[mysqld]
#### for basic
user                                     = {{user}}
basedir                                  = {{basedir}}
datadir                                  = {{datadir}}
server_id                                = {{server_id}}
port                                     = {{port}}
character_set_server                     = utf8mb4 
log_bin_trust_function_creators          = {{ log_bin_trust_function_creators }}  
max_prepared_stmt_count                  = {{ max_prepared_stmt_count }}          
log_timestamps                           = {{ log_timestamps }}                   
socket                                   = {{ socket }}                           
read_only                                = {{ read_only }}                        
skip_name_resolve                        = {{ skip_name_resolve }}                
auto_increment_increment                 = {{ auto_increment_increment }}         
auto_increment_offset                    = {{ auto_increment_offset }}            
lower_case_table_names                   = {{ lower_case_table_names }}           
secure_file_priv                         = null                                   
open_files_limit                         = {{ open_files_limit }}                 
max_connections                          = {{ max_connections }}                  
thread_cache_size                        = {{ thread_cache_size }}                
table_open_cache                         = {{ table_open_cache }}                 
table_definition_cache                   = {{ table_definition_cache }}           
table_open_cache_instances               = {{ table_open_cache_instances }}   


#### for logs 
log_output                               = {{log_output}}
general_log                              = {{general_log}}
general_log_file                         = {{general_log_file}}


## error
log_error                                = {{log_error}}
log_statements_unsafe_for_binlog         = {{log_statements_unsafe_for_binlog}}


## for slow
slow_query_log                           = {{slow_query_log}}
slow_query_log_file                      = {{slow_query_log_file}}
long_query_time                          = {{long_query_time}}
log_queries_not_using_indexes            = {{log_queries_not_using_indexes}}
log_slow_admin_statements                = {{log_slow_admin_statements}}


## for binlog
log_bin                                    = {{log_bin }}
binlog_checksum                            = {{binlog_checksum}}
log_bin_trust_function_creators            = {{log_bin_trust_function_creators}}
binlog_direct_non_transactional_updates    = {{binlog_direct_non_transactional_updates}}
binlog_error_action                        = {{binlog_error_action}}
binlog_format                              = {{binlog_format}}
max_binlog_stmt_cache_size                 = {{max_binlog_stmt_cache_size}}
max_binlog_cache_size                      = {{max_binlog_cache_size}}
max_binlog_size                            = {{max_binlog_size}}
binlog_order_commits                       = {{binlog_order_commits}}
binlog_row_image                           = {{binlog_row_image}}
binlog_rows_query_log_events               = {{binlog_rows_query_log_events}}
binlog_stmt_cache_size                     = {{binlog_stmt_cache_size}}
sync_binlog                                = {{sync_binlog}}
binlog_cache_size                          = {{binlog_cache_size}}


#### for gtid
gtid_mode                                = {{gtid_mode}}
binlog_gtid_simple_recovery              = {{binlog_gtid_simple_recovery}}
enforce_gtid_consistency                 = {{enforce_gtid_consistency}}
gtid_executed_compression_period         = {{gtid_executed_compression_period}}


#### for engines 
default_storage_engine                   = {{default_storage_engine}}
default_tmp_storage_engine               = {{default_tmp_storage_engine}}


#### for innodb
innodb_data_home_dir                     = {{innodb_data_home_dir}}
innodb_data_file_path                    = {{innodb_data_file_path}}
innodb_page_size                         = {{innodb_page_size}}
innodb_default_row_format                = {{innodb_default_row_format}}
innodb_online_alter_log_max_size         = {{innodb_online_alter_log_max_size}}
innodb_undo_log_truncate                 = {{innodb_undo_log_truncate}}
innodb_max_undo_log_size                 = {{innodb_max_undo_log_size}}
innodb_rollback_on_timeout               = {{innodb_rollback_on_timeout}}
innodb_rollback_segments                 = {{innodb_rollback_segments}}
innodb_log_checksums                     = {{innodb_log_checksums}}
innodb_checksum_algorithm                = {{innodb_checksum_algorithm}}
innodb_log_compressed_pages              = {{innodb_log_compressed_pages}}
innodb_doublewrite                       = {{innodb_doublewrite}}
innodb_commit_concurrency                = {{innodb_commit_concurrency}}
innodb_read_only                         = {{innodb_read_only}}
innodb_old_blocks_pct                    = {{innodb_old_blocks_pct}}
innodb_old_blocks_time                   = {{innodb_old_blocks_time}}
innodb_random_read_ahead                 = {{innodb_random_read_ahead}}
innodb_read_ahead_threshold              = {{innodb_read_ahead_threshold}}
innodb_max_dirty_pages_pct_lwm           = {{innodb_max_dirty_pages_pct_lwm}}
innodb_max_dirty_pages_pct               = {{innodb_max_dirty_pages_pct}}
innodb_lru_scan_depth                    = {{innodb_lru_scan_depth}}
innodb_adaptive_flushing                 = {{innodb_adaptive_flushing}}
innodb_adaptive_flushing_lwm             = {{innodb_adaptive_flushing_lwm}}
innodb_flushing_avg_loops                = {{innodb_flushing_avg_loops}}
innodb_buffer_pool_dump_pct              = {{innodb_buffer_pool_dump_pct}}
innodb_buffer_pool_dump_at_shutdown      = {{innodb_buffer_pool_dump_at_shutdown}}
innodb_buffer_pool_load_at_startup       = {{innodb_buffer_pool_load_at_startup}}
innodb_buffer_pool_filename              = {{innodb_buffer_pool_filename}}
innodb_stats_persistent                  = {{innodb_stats_persistent}}
innodb_stats_on_metadata                 = {{innodb_stats_on_metadata}}
innodb_stats_method                      = {{innodb_stats_method}}
innodb_stats_auto_recalc                 = {{innodb_stats_auto_recalc}}
innodb_stats_include_delete_marked       = {{innodb_stats_include_delete_marked}}
innodb_stats_persistent_sample_pages     = {{innodb_stats_persistent_sample_pages}}
innodb_stats_transient_sample_pages      = {{innodb_stats_transient_sample_pages}}
innodb_status_output                     = {{innodb_status_output}}
innodb_status_output_locks               = {{innodb_status_output_locks}}
innodb_buffer_pool_dump_now              = {{innodb_buffer_pool_dump_now}}
innodb_buffer_pool_load_abort            = {{innodb_buffer_pool_load_abort}}
innodb_buffer_pool_load_now              = {{innodb_buffer_pool_load_now}}
innodb_thread_concurrency                = {{innodb_thread_concurrency}}
innodb_concurrency_tickets               = {{innodb_concurrency_tickets}}
innodb_thread_sleep_delay                = {{innodb_thread_sleep_delay}}
innodb_adaptive_max_sleep_delay          = {{innodb_adaptive_max_sleep_delay}}
innodb_read_io_threads                   = {{innodb_read_io_threads}}
innodb_write_io_threads                  = {{innodb_write_io_threads}}
innodb_use_native_aio                    = {{innodb_use_native_aio}}
innodb_flush_sync                        = {{innodb_flush_sync}}
innodb_spin_wait_delay                   = {{innodb_spin_wait_delay}}
innodb_purge_threads                     = {{innodb_purge_threads }}
innodb_purge_batch_size                  = {{innodb_purge_batch_size}}
innodb_purge_rseg_truncate_frequency     = {{innodb_purge_rseg_truncate_frequency}}
innodb_deadlock_detect                   = {{innodb_deadlock_detect}}
innodb_print_all_deadlocks               = {{innodb_print_all_deadlocks}}
innodb_lock_wait_timeout                 = {{innodb_lock_wait_timeout}}
innodb_table_locks                       = {{innodb_table_locks}}
innodb_sync_array_size                   = {{innodb_sync_array_size}}
innodb_sync_spin_loops                   = {{innodb_sync_spin_loops}}
innodb_replication_delay                 = {{innodb_replication_delay}}
innodb_cmp_per_index_enabled             = {{innodb_cmp_per_index_enabled}}
innodb_disable_sort_file_cache           = {{innodb_disable_sort_file_cache}}
innodb_numa_interleave                   = {{innodb_numa_interleave}}
innodb_strict_mode                       = {{innodb_strict_mode}}
innodb_sort_buffer_size                  = {{innodb_sort_buffer_size}}
innodb_fast_shutdown                     = {{innodb_fast_shutdown}}
innodb_force_load_corrupted              = {{innodb_force_load_corrupted}}
innodb_force_recovery                    = {{innodb_force_recovery}}
innodb_tmpdir                            = {{innodb_tmpdir}}
innodb_temp_data_file_path               = {{innodb_temp_data_file_path}}
innodb_page_cleaners                     = {{innodb_page_cleaners}}
innodb_adaptive_hash_index               = {{innodb_adaptive_hash_index}}
innodb_adaptive_hash_index_parts         = {{innodb_adaptive_hash_index_parts}}
innodb_flush_log_at_timeout              = {{innodb_flush_log_at_timeout}}
innodb_fill_factor                       = {{innodb_fill_factor}}
innodb_file_per_table                    = {{innodb_file_per_table}}
innodb_autoextend_increment              = {{innodb_autoextend_increment}}
innodb_open_files                        = {{innodb_open_files}}
innodb_buffer_pool_chunk_size            = {{innodb_buffer_pool_chunk_size}}
innodb_buffer_pool_instances             = {{innodb_buffer_pool_instances}}
innodb_log_files_in_group                = {{innodb_log_files_in_group}}
innodb_log_file_size                     = {{innodb_log_file_size}}
innodb_flush_neighbors                   = {{innodb_flush_neighbors}}
innodb_io_capacity                       = {{innodb_io_capacity}}
innodb_io_capacity_max                   = {{innodb_io_capacity_max}}
innodb_autoinc_lock_mode                 = {{innodb_autoinc_lock_mode}}
innodb_change_buffer_max_size            = {{innodb_change_buffer_max_size}}
innodb_flush_method                      = {{innodb_flush_method}}
innodb_log_buffer_size                   = {{innodb_log_buffer_size}}
innodb_flush_log_at_trx_commit           = {{innodb_flush_log_at_trx_commit}}
innodb_buffer_pool_size                  = {{innodb_buffer_pool_size}}


# -- ~ _ ~    ~ _ ~     ~ _ ~ -- 
# base on mysql-5.7.x
# generated by https://www.sqlpy.com 2022年11月11日 23:45
# wechat: jianglegege
# email: 1721900707@qq.com
# -- ~ _ ~ --
 